

#include "pitches.h"

/* Define pin numbers for LEDs, buttons and speaker: */
const uint8_t buttonPin = {1};
int potPins[] = {4, 9};

const uint8_t ledPins[] = {8, 7, 6, 5};
#define buzzerPin 10

// Variables
int chaosMode = 0; // Chaos mode level
unsigned long lastChaosTime = 0;
const unsigned long chaosInterval = 5000; // Chaos event every 5 seconds

void setup() {
  Serial.begin(115200);

  // Initialize pins
  for (int i = 0; i < 4; i++) {
    pinMode(ledPins[i], OUTPUT);
  }
  pinMode(buttonPin, INPUT_PULLDOWN);
  pinMode(buzzerPin, OUTPUT);

  // Print instructions
  Serial.println("ESP32 Party Chaos Synthesizer");
}

void loop() {
  // Read potentiometers
  int pitch = analogRead(potPins[0]) / 4; // Scale to 0-1023
  int duration = analogRead(potPins[1]) / 4;

  // Play a tone
  tone(buzzerPin, pitch, duration);
  delay(duration);

  // LED blink patterns
  for (int i = 0; i < 4; i++) {
    digitalWrite(ledPins[i], random(0, 2));
  }

  // Check button press for chaos mode
  if (digitalRead(buttonPin) == HIGH) {
    Serial.println("CHAOS MODE ACTIVATED!");
    triggerChaos();
    delay(300); // Debounce
  }

  // Periodic chaos events
  if (millis() - lastChaosTime > chaosInterval) {
    lastChaosTime = millis();
    Serial.println("Random Chaos Event!");
    triggerChaos();
  }
}

// Chaos mode: Random weirdness!
void triggerChaos() {
  chaosMode = random(0, 3);

  switch (chaosMode) {
    case 0:
      Serial.println("Reversing potentiometer controls!");
      reversePotentiometers();
      break;

    case 1:
      Serial.println("Random LED madness!");
      randomLEDPatterns();
      break;

    case 2:
      Serial.println("Unpredictable sounds!");
      unpredictableSounds();
      break;
  }
}

// Reverse potentiometer readings
void reversePotentiometers() {
  int temp = potPins[9];
  potPins[9] = potPins[4];
  potPins[4] = temp;
}

// Random LED patterns
void randomLEDPatterns() {
  for (int i = 0; i < 10; i++) {
    for (int j = 0; j < 4; j++) {
      digitalWrite(ledPins[j], random(0, 2));
    }
    delay(100);
  }
}

// Unpredictable sounds
void unpredictableSounds() {
  for (int i = 0; i < 10; i++) {
    tone(buzzerPin, random(100, 2000), random(100, 500));
    delay(random(100, 500));
  }
}